(function (React, ReactDOM, d3) {
    'use strict';
    var React__default = 'default' in React ? React['default'] : React;
    ReactDOM = ReactDOM && Object.prototype.hasOwnProperty.call(ReactDOM, 'default') ? ReactDOM['default'] : ReactDOM;
    const csvUrl =
      'https://gist.githubusercontent.com/saijahnaviappineni/a3f3ae6865d15040da8d5a06bb6bfee3/raw/f1d666a5ff795e569b95d5e42ad12e87caf87c6a/dsjob.csv';
    const width = 960;
    const height = 500;
    const margin = { top: 5, right: 20, bottom:80, left: 200 };
    const App = () => {
      const [data, setData] = React.useState(null);
      React.useEffect(() => {
        const row = d => {
          d.salary = +d['Salary_estimation(thousands)'];
          return d;
        };
        d3.csv(csvUrl, row).then(data => {
          setData(data.slice(0, 10));
        });
      }, []);
      if (!data) {
        return React__default.createElement( 'pre', null, "Loading..." );
      }
      const innerHeight = height - margin.top - margin.bottom - 100;
      const innerWidth = width - margin.left - margin.right;
      const yScale = d3.scaleBand()
        .domain(data.map(d => d.Job_title))
        .range([0, innerHeight]);
      const xScale = d3.scaleLinear()
        .domain([0, d3.max(data, d => d.salary)])
        .range([0, innerWidth]);
      return (
        React__default.createElement( 'svg', { width: width, height: height },
          React__default.createElement( 'g', { transform: `translate(${margin.left},${margin.top})` },
            xScale.ticks().map(tickValue => (
              React__default.createElement( 'g', { key: tickValue, transform: `translate(${xScale(tickValue)},0)` },
                React__default.createElement( 'line', { y2: innerHeight, stroke: "black" }),
                React__default.createElement( 'text', {
                  style: { textAnchor: 'middle' }, dy: ".7em", y: innerHeight + 3 },
                  tickValue
                )
              )
            )),
            yScale.domain().map(tickValue => (
              React__default.createElement( 'text', {
                key: tickValue, style: { textAnchor: 'end' }, x: -5, dy: "1em", y: yScale(tickValue) + yScale.bandwidth() / 3 },
                tickValue
              )
            )),
            data.map(d => (
              React__default.createElement( 'rect', {
                key: d.Job_title, x: 0, y: yScale(d.Job_title), width: xScale(d.salary), height: yScale.bandwidth() })
            ))
          )
        )
      );
    };
    const rootElement = document.getElementById('root');
    ReactDOM.render(React__default.createElement( App, null ), rootElement);
  }(React, ReactDOM, d3));